abacusai.data_metrics — AbacusAI documentation

# abacusai.data_metrics

## Classes

`AbstractApiClass` |
`DataMetrics` | Processed Metrics and Schema for a dataset version or feature group version

## Module Contents

class abacusai.data_metrics.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.data_metrics.DataMetrics(client, metrics=None, schema=None, numRows=None, numCols=None, numDuplicateRows=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Processed Metrics and Schema for a dataset version or feature group version

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - metrics (list[dict]) – A list of dicts with metrics for each columns

    - schema (list[dict]) – A list of dicts with the schema for each metric

    - numRows (int) – The number of rows

    - numCols (int) – The number of columns

    - numDuplicateRows (int) – The number of duplicate rows

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict